aboutsummaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/numerics.h2
-rw-r--r--include/server.h24
-rw-r--r--include/usermanager.h12
3 files changed, 18 insertions, 20 deletions
diff --git a/include/numerics.h b/include/numerics.h
index 8d07259d6..de6b92325 100644
--- a/include/numerics.h
+++ b/include/numerics.h
@@ -154,7 +154,7 @@ enum
ERR_BANLISTFULL = 478,
ERR_NOPRIVILEGES = 481, // rfc, beware though, we use this for other things opers may not do also
- ERR_CHANOPRIVSNEEDED = 482, // rfc, beware though, we use this for other things like trying to kick a uline
+ ERR_CHANOPRIVSNEEDED = 482,
ERR_RESTRICTED = 484,
diff --git a/include/server.h b/include/server.h
index 107ad69e9..cf9637765 100644
--- a/include/server.h
+++ b/include/server.h
@@ -36,13 +36,11 @@ class CoreExport Server : public classbase
*/
std::string description;
- /** True if this server is ulined
- */
- bool uline = false;
+ /** True if this server is a service. */
+ bool service = false;
- /** True if this server is a silent uline, i.e. silent="yes" in the uline block
- */
- bool silentuline = false;
+ /** True if this server is a silent service, i.e. silent="yes" in the service block. */
+ bool silentservice = false;
/** Allow ConfigReaderThread to update the description on a rehash
*/
@@ -71,15 +69,15 @@ class CoreExport Server : public classbase
const std::string& GetDesc() const { return description; }
/**
* Checks whether this server is ulined
* @return True if this server is ulined, false otherwise.
*/
- bool IsULine() const { return uline; }
+ bool IsService() const { return service; }
/**
* Checks whether this server is a silent uline
* Silent uline servers introduce, quit and oper up users without a snotice being generated.
* @return True if this server is a silent uline, false otherwise.
*/
- bool IsSilentULine() const { return silentuline; }
+ bool IsSilentService() const { return silentservice; }
};
@@ -71,15 +69,15 @@ class CoreExport Server : public classbase
const std::string& GetDesc() const { return description; }
/**
- * Checks whether this server is ulined
- * @return True if this server is ulined, false otherwise.
+ * Checks whether this server is a service.
+ * @return True if this server is a service, false otherwise.
*/
@@ -71,15 +69,15 @@ class CoreExport Server : public classbase
/**
- * Checks whether this server is a silent uline
- * Silent uline servers introduce, quit and oper up users without a snotice being generated.
- * @return True if this server is a silent uline, false otherwise.
+ * Checks whether this server is a silent service.
+ * Silent services servers introduce, quit and oper up users without a snotice being generated.
+ * @return True if this server is a silent service, false otherwise.
*/
diff --git a/include/usermanager.h b/include/usermanager.h
index 48990e05e..acbf3ca1f 100644
--- a/include/usermanager.h
+++ b/include/usermanager.h
@@ -46,7 +46,7 @@ class CoreExport UserManager
typedef std::vector<User*> OperList;
/** A list containing users who are on a U-lined servers. */
- typedef std::vector<User*> ULineList;
+ typedef std::vector<User*> ServiceList;
/** A list holding local users
*/
@@ -91,8 +91,8 @@ class CoreExport UserManager
*/
OperList all_opers;
- /** A list of users on U-lined servers. */
- ULineList all_ulines;
+ /** A list of users on services servers. */
+ ServiceList all_services;
/** Number of unregistered users online right now.
* (Unregistered means before USER/NICK/dns)
@@ -164,10 +164,10 @@ class CoreExport UserManager
*/
unsigned int UnregisteredUserCount() const { return this->unregistered_count; }
/** Return a count of users on a u-lined servers.
* @return The number of users on u-lined servers.
*/
- unsigned int ULineCount() const { return this->all_ulines.size(); }
+ unsigned int ULineCount() const { return this->all_services.size(); }
/** Return a count of local registered users
* @return The number of registered local users
@@ -164,10 +164,10 @@ class CoreExport UserManager
*/
unsigned int UnregisteredUserCount() const { return this->unregistered_count; }
- /** Return a count of users on a u-lined servers.
- * @return The number of users on u-lined servers.
+ /** Return a count of users on a services servers.
+ * @return The number of users on services servers.
*/